==> blemulator-1.0.0-dev.1.tar.gz: ios/Classes/Bridging/Converter/DomainTypesConverter.m <==
#import "DomainTypesConverter.h"
#import "DartResultKeys.h"

@implementation DomainTypesConverter

+ (Service *)serviceFromDictionary:(NSDictionary *)dictionary {
    return [[Service alloc] initWithObjectId:[[dictionary objectForKey:DART_RESULT_SERVICE_ID] intValue]
                                        uuid:[CBUUID UUIDWithString:[dictionary objectForKey:DART_RESULT_SERVICE_UUID]]
                        peripheralIdentifier:[dictionary objectForKey:DART_RESULT_DEVICE_IDENTIFIER]
                                   isPrimary:true];
}

+ (Characteristic *)characteristicFromDictionary:(NSDictionary *)dictionary service:(Service *)service {
    id value = [dictionary objectForKey:DART_RESULT_VALUE] != [NSNull null] ?
    (NSData *)[dictionary objectForKey:DART_RESULT_VALUE] : nil;
    return [[Characteristic alloc] initWithObjectId:[[dictionary objectForKey:DART_RESULT_CHARACTERISTIC_ID] intValue]
                                               uuid:[CBUUID UUIDWithString:[dictionary objectForKey:DART_RESULT_CHARACTERISTIC_UUID]]
                                              value:value
                                            service:service
                                        isNotifying:[[dictionary objectForKey:DART_RESULT_IS_NOTIFYING] boolValue]
                                         properties:[self calculatePropertiesFor:dictionary]];
}

+ (CBCharacteristicProperties)calculatePropertiesFor:(NSDictionary *)characteristicDictionary {
    CBCharacteristicProperties properties = 0;

    BOOL isReadable = [[characteristicDictionary objectForKey:DART_RESULT_IS_READABLE] boolValue];
    BOOL isWritableWithResponse = [[characteristicDictionary objectForKey:DART_RESULT_IS_WRITABLE_WITH_RESPONSE] boolValue];
    BOOL isWritableWithoutResponse = [[characteristicDictionary objectForKey:DART_RESULT_IS_WRITABLE_WITHOUT_RESPONSE] boolValue];
    BOOL isNotifiable = [[characteristicDictionary objectForKey:DART_RESULT_IS_NOTIFIABLE] boolValue];
    BOOL isIndicatable = [[characteristicDictionary objectForKey:DART_RESULT_IS_INDICATABLE] boolValue];

    if (isReadable) { properties |= CBCharacteristicPropertyRead; }
    if (isWritableWithResponse) { properties |= CBCharacteristicPropertyWrite; }
    if (isWritableWithoutResponse) { properties |= CBCharacteristicPropertyWriteWithoutResponse; }
    if (isNotifiable) { properties |= CBCharacteristicPropertyNotify; }
    if (isIndicatable) { properties |= CBCharacteristicPropertyIndicate; }

    return properties;
}

@end

==> blemulator-1.2.1.tar.gz: ios/Classes/Bridging/Converter/DomainTypesConverter.m <==
#import "DomainTypesConverter.h"
#import "DartResultKeys.h"

@implementation DomainTypesConverter

+ (Service *)serviceFromDictionary:(NSDictionary *)dictionary
          withPeripheralIdentifier:(NSString *)peripheralIdentifier {
    return [[Service alloc] initWithObjectId:[[dictionary objectForKey:DART_RESULT_SERVICE_ID] intValue]
                                        uuid:[CBUUID UUIDWithString:[dictionary objectForKey:DART_RESULT_SERVICE_UUID]]
                        peripheralIdentifier:peripheralIdentifier
                                   isPrimary:true];
}

+ (Characteristic *)characteristicFromDictionary:(NSDictionary *)dictionary service:(Service *)service {
    id value = [dictionary objectForKey:DART_RESULT_VALUE] != [NSNull null] ?
    (NSData *)[dictionary objectForKey:DART_RESULT_VALUE] : nil;
    return [[Characteristic alloc] initWithObjectId:[[dictionary objectForKey:DART_RESULT_CHARACTERISTIC_ID] intValue]
                                               uuid:[CBUUID UUIDWithString:[dictionary objectForKey:DART_RESULT_CHARACTERISTIC_UUID]]
                                              value:value
                                            service:service
                                        isNotifying:[[dictionary objectForKey:DART_RESULT_IS_NOTIFYING] boolValue]
                                         properties:[self calculatePropertiesFor:dictionary]];
}


+ (Descriptor *)descriptorFromDictionary:(NSDictionary *)dictionary
                          characteristic:(Characteristic *)characteristic {
    id value = [dictionary objectForKey:DART_RESULT_VALUE] != [NSNull null] ? (NSData *)[dictionary objectForKey:DART_RESULT_VALUE] : nil;
    return [[Descriptor alloc] initWithObjectId:[[dictionary objectForKey:DART_RESULT_DESCRIPTOR_ID] intValue]
                                           uuid:[CBUUID UUIDWithString:[dictionary objectForKey:DART_RESULT_DESCRIPTOR_UUID]]
                                          value:value
                                 characteristic:characteristic];
    
}

+ (CBCharacteristicProperties)calculatePropertiesFor:(NSDictionary *)characteristicDictionary {
    CBCharacteristicProperties properties = 0;

    BOOL isReadable = [[characteristicDictionary objectForKey:DART_RESULT_IS_READABLE] boolValue];
    BOOL isWritableWithResponse = [[characteristicDictionary objectForKey:DART_RESULT_IS_WRITABLE_WITH_RESPONSE] boolValue];
    BOOL isWritableWithoutResponse = [[characteristicDictionary objectForKey:DART_RESULT_IS_WRITABLE_WITHOUT_RESPONSE] boolValue];
    BOOL isNotifiable = [[characteristicDictionary objectForKey:DART_RESULT_IS_NOTIFIABLE] boolValue];
    BOOL isIndicatable = [[characteristicDictionary objectForKey:DART_RESULT_IS_INDICATABLE] boolValue];

    if (isReadable) { properties |= CBCharacteristicPropertyRead; }
    if (isWritableWithResponse) { properties |= CBCharacteristicPropertyWrite; }
    if (isWritableWithoutResponse) { properties |= CBCharacteristicPropertyWriteWithoutResponse; }
    if (isNotifiable) { properties |= CBCharacteristicPropertyNotify; }
    if (isIndicatable) { properties |= CBCharacteristicPropertyIndicate; }

    return properties;
}

@end
